@@ -24,7 +24,6 @@ use gio::{
 use glib::{ControlFlow, OptionArg, OptionFlags, Priority, Propagation, Properties, SourceId};
 use gtk4::{CssProvider, IconTheme, prelude::*};
 use libadwaita::subclass::prelude::*;
-use log::{info, warn};
 use news_flash::models::{FeedID, LoginData, PluginCapabilities, PluginID};
 use news_flash::{NewsFlash, error::NewsFlashError};
 use once_cell::sync::Lazy;
@@ -33,6 +32,7 @@ use tokio::time::Duration;
 
 pub static CONFIG_DIR: Lazy<PathBuf> = Lazy::new(|| glib::user_config_dir().join("news-flash"));
 pub static DATA_DIR: Lazy<PathBuf> = Lazy::new(|| glib::user_data_dir().join("news-flash"));
+pub static STATE_DIR: Lazy<PathBuf> = Lazy::new(|| glib::user_state_dir().join("news-flash"));
 pub static WEBKIT_DATA_DIR: Lazy<PathBuf> = Lazy::new(|| DATA_DIR.join("Webkit"));
 pub static IMAGE_DATA_DIR: Lazy<PathBuf> = Lazy::new(|| DATA_DIR.join("pictures"));
 
@@ -100,14 +100,14 @@ mod imp {
         type ParentType = libadwaita::Application;
 
         fn new() -> Self {
-            info!("Newsflash {VERSION} ({APP_ID})");
+            tracing::info!(%VERSION, %APP_ID, "Newsflash");
 
             let news_flash_lib = NewsFlash::try_load(&DATA_DIR, &CONFIG_DIR).ok();
 
             if news_flash_lib.is_some() {
-                info!("Successful load from config");
+                tracing::info!("Successful load from config");
             } else {
-                warn!("No account configured");
+                tracing::warn!("No account configured");
             }
 
             let news_flash = Arc::new(RwLock::new(news_flash_lib));
@@ -329,9 +329,9 @@ mod imp {
                     if !network_monitor.is_network_available()
                         && network_monitor.connectivity() != NetworkConnectivity::Full
                     {
-                        log::warn!("Omitting startup sync due to no network connectivity");
+                        tracing::warn!("Omitting startup sync due to no network connectivity");
                     } else {
-                        info!("Startup Sync");
+                        tracing::info!("Startup Sync");
                         super::App::default().activate_action("sync", None);
                     }
 
@@ -348,7 +348,7 @@ mod imp {
                     news_flash.id().await
                 },
                 move |plugin_id| {
-                    log::info!("plugin id {plugin_id:?}");
+                    tracing::info!(?plugin_id);
                     super::App::default().set_plugin_id(plugin_id.map(|id| id.as_str().to_owned()));
                 },
             );
@@ -428,23 +428,23 @@ impl App {
             app.activate();
 
             if let Ok(Some(subscribe_url)) = options.lookup::<String>("subscribe") {
-                log::info!("subscribe {subscribe_url}");
+                tracing::info!(%subscribe_url);
                 MainWindow::activate_action("add-feed-dialog", Some(&subscribe_url.to_variant()));
             }
 
-            0
+            0.into()
         });
-        app.connect_handle_local_options(|app, options| {
+        app.connect_handle_local_options(move |app, options| {
             if options.contains("inspect") {
                 app.settings().set_inspect_article_view(true);
             }
 
             if options.contains("headless") {
-                log::info!("starting headless");
+                tracing::info!("starting headless");
                 app.imp().start_headless.set(true);
             }
 
-            -1
+            std::ops::ControlFlow::Continue(())
         });
 
         app.add_action_entries([ActionEntry::builder("quit")
@@ -502,11 +502,11 @@ impl App {
                 .map(|feed_settings| feed_settings.mute_notifications)
                 .unwrap_or(false)
             {
-                log::debug!("{feed_id} notifications muted");
+                tracing::debug!(%feed_id, "notifications muted");
                 continue;
             }
 
-            log::debug!("feed {feed_id} new count: {new}");
+            tracing::debug!(%feed_id, %new, "feed new count");
             new_count += new;
             unread_count += *counts.unread.get(&feed_id).unwrap_or(&0);
         }
@@ -621,7 +621,7 @@ impl App {
             SyncIntervalType::Predefined => general_settings.predefined_sync_interval().as_seconds(),
             SyncIntervalType::Custom => Some(general_settings.custom_sync_interval()),
         };
-        log::info!("schedule sync: {sync_interval:?}");
+        tracing::info!(?sync_interval, "schedule sync");
         let sync_on_metered_connection = self.settings().general().sync_on_metered();
 
         let Some(sync_interval) = sync_interval else {
@@ -683,7 +683,7 @@ impl App {
     }
 
     fn force_quit(&self) {
-        info!("Shutdown!");
+        tracing::info!("Shutdown!");
         MainWindow::harvest_restore_relevant_state();
         self.quit();
     }
@@ -691,7 +691,7 @@ impl App {
     pub fn request_background_permission(autostart: bool) {
         let root = MainWindow::instance().native().unwrap();
 
-        log::info!("request background permissions (autostart {autostart})");
+        tracing::info!(%autostart, "request background permissions");
 
         glib::MainContext::default().spawn_local_with_priority(Priority::LOW, async move {
             if !ashpd::is_sandboxed().await {
@@ -711,14 +711,14 @@ impl App {
                 .and_then(|request| request.response());
 
             if let Err(error) = response {
-                log::error!("Requesting background permission failed: {error}");
+                tracing::error!(%error, "Requesting background permission failed");
             }
 
             let proxy = ashpd::desktop::background::BackgroundProxy::new().await;
             if let Ok(proxy) = proxy
                 && let Err(error) = proxy.set_status(constants::BACKGROUND_IDLE).await
             {
-                log::error!("Failed to set background message: {error}");
+                tracing::error!(%error, "Failed to set background message");
             }
         });
     }
@@ -733,7 +733,7 @@ impl App {
             if let Ok(proxy) = proxy
                 && let Err(error) = proxy.set_status(message).await
             {
-                log::error!("Failed to set background message: {error}");
+                tracing::error!(%error, "Failed to set background message");
             }
         });
     }
