@@ -27,8 +27,9 @@ use diffus::edit::{Edit, collection};
 use gio::ListStore;
 use glib::{ControlFlow, Object, Properties, SourceId, clone, subclass};
 use gtk4::{
-    Box, CompositeTemplate, CustomSorter, ListHeader, ListItem, ListScrollFlags, ListView, NamedAction, Ordering,
-    Shortcut, SingleSelection, Stack, StackTransitionType, Widget, prelude::*, subclass::prelude::*,
+    Accessible, Box, Buildable, CompositeTemplate, ConstraintTarget, CustomSorter, ListHeader, ListItem,
+    ListScrollFlags, ListView, NamedAction, Ordering, Shortcut, SingleSelection, Stack, StackTransitionType, Widget,
+    prelude::*, subclass::prelude::*,
 };
 use libadwaita::StatusPage;
 pub use load_queue::ArticleListLoadQueue;
@@ -223,7 +224,8 @@ mod imp {
                     clone!(
                         #[weak(rename_to = imp)]
                         self,
-                        #[upgrade_or_panic]
+                        #[upgrade_or]
+                        ControlFlow::Break,
                         move || {
                             imp.delayed_selection.take();
                             activate(&imp);
@@ -477,9 +479,8 @@ mod imp {
             }
 
             // select now, but activate 300ms later
-            let inner_splitview = ContentPage::instance().inner().clone();
-            let delay_next = !inner_splitview.is_collapsed() || !inner_splitview.shows_content();
-            self.delay_next_activation.set(delay_next);
+            let article_list_visibble = ContentPage::instance().is_article_list_visible();
+            self.delay_next_activation.set(article_list_visibble);
             self.selection.select_item(new_item_pos as u32, true);
             self.listview
                 .scroll_to(new_item_pos as u32, ListScrollFlags::NONE, None);
@@ -501,7 +502,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct ArticleList(ObjectSubclass<imp::ArticleList>)
-        @extends Widget, Box;
+        @extends Widget, Box,
+        @implements Accessible, Buildable, ConstraintTarget;
 }
 
 impl Default for ArticleList {
