@@ -12,8 +12,9 @@ use gdk4::RGBA;
 use gio::Cancellable;
 use glib::{ControlFlow, Object, Properties, SignalHandlerId, SourceId, clone, prelude::*, subclass::*};
 use gtk4::{
-    CompositeTemplate, EventController, EventControllerMotion, EventControllerScroll, PolicyType, PropagationPhase,
-    ScrolledWindow, Stack, Widget, prelude::*, subclass::prelude::*,
+    Accessible, Buildable, CompositeTemplate, ConstraintTarget, EventController, EventControllerMotion,
+    EventControllerScroll, PolicyType, PropagationPhase, ScrolledWindow, Stack, Widget, prelude::*,
+    subclass::prelude::*,
 };
 use libadwaita::{Bin, subclass::prelude::*};
 use news_flash::models::Url;
@@ -149,12 +150,13 @@ mod imp {
             let web_context = WebContext::new();
             web_context.set_cache_model(CacheModel::DocumentViewer);
 
-            log::info!(
-                "WebKit version: {}.{}.{}",
+            let webkit_version = format!(
+                "{}.{}.{}",
                 webkit6::functions::major_version(),
                 webkit6::functions::minor_version(),
                 webkit6::functions::micro_version()
             );
+            tracing::info!(%webkit_version);
 
             self.web_context.replace(web_context);
             self.network_session.replace(network_session);
@@ -280,7 +282,7 @@ mod imp {
                             return false;
                         };
 
-                        log::debug!("navigation action uri: {uri}");
+                        tracing::debug!(%uri, "navigation action");
 
                         if let Some(base_uri) = obj.base_uri() {
                             let suffix = uri.strip_prefix(base_uri.as_str()).unwrap_or_default();
@@ -479,9 +481,9 @@ mod imp {
                 move |result| {
                     if let Ok(filter) = result {
                         user_content_manager.add_filter(&filter);
-                        log::debug!("Stylesheet filter loaded");
+                        tracing::debug!("Stylesheet filter loaded");
                     } else if let Err(error) = result {
-                        log::error!("Failed to load Stylesheet filter: {error}");
+                        tracing::error!(%error, "Failed to load Stylesheet filter");
                     }
                 },
             );
@@ -495,9 +497,9 @@ mod imp {
                 move |result| {
                     if let Ok(filter) = result {
                         user_content_manager_clone.add_filter(&filter);
-                        log::debug!("Easylist adblock filter loaded");
+                        tracing::debug!("Easylist adblock filter loaded");
                     } else if let Err(error) = result {
-                        log::error!("Failed to load Easylist adblock filter: {error}");
+                        tracing::error!(%error, "Failed to load Easylist adblock filter");
                     }
                 },
             );
@@ -505,6 +507,7 @@ mod imp {
 
         pub fn load_user_data(&self) {
             let Some(user_content_manager) = self.view.borrow().user_content_manager() else {
+                tracing::trace!("no user content manager");
                 return;
             };
 
@@ -549,10 +552,7 @@ mod imp {
                     #[weak(rename_to = imp)]
                     self,
                     move |_manager, js_value| {
-                        // return if an image dialog is already visible
-                        if imp.image_dialog_visible.get() {
-                            return;
-                        }
+                        tracing::trace!("contentSize event from js");
 
                         let upper_str = js_value.to_str();
                         let upper = upper_str.parse::<i32>().unwrap();
@@ -561,6 +561,8 @@ mod imp {
                     }
                 ),
             );
+
+            tracing::trace!("javascript userdata loaded");
         }
 
         fn generate_img_dialog_js() -> UserScript {
@@ -663,7 +665,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct Webview(ObjectSubclass<imp::Webview>)
-        @extends Widget, Bin;
+        @extends Widget, Bin,
+        @implements Accessible, Buildable, ConstraintTarget;
 }
 
 impl Default for Webview {
@@ -748,7 +751,7 @@ impl Webview {
             Cancellable::NONE,
             move |res| {
                 if let Err(error) = res {
-                    log::error!("Failed to clear webkit cache: {error}");
+                    tracing::error!(%error, "Failed to clear webkit cache");
                 }
                 oneshot_sender.send(()).expect(CHANNEL_ERROR);
             },
