@@ -2,16 +2,18 @@ use crate::app::App;
 use crate::article_list::{MarkUpdate, ReadUpdate};
 use crate::article_view::{ArticleLoader, ArticleView};
 use crate::gobject_models::{GArticle, GArticleID, GMarked, GRead};
+use crate::i18n::i18n;
 use crate::infrastructure::TokioRuntime;
 use crate::main_window::MainWindow;
+use crate::settings::Keybindings;
 use crate::share::share_popover::SharePopover;
 use crate::tag_popover::TagPopover;
 use crate::util::constants;
 use gio::{SimpleAction, SimpleActionGroup};
-use glib::{Properties, SignalHandlerId, clone, subclass::prelude::*, subclass::*};
+use glib::{Object, Properties, SignalHandlerId, clone, subclass::prelude::*, subclass::*};
 use gtk4::{
-    Button, CompositeTemplate, GestureClick, MenuButton, NamedAction, Orientation, PopoverMenu, Shortcut, Stack,
-    ToggleButton, prelude::*, subclass::prelude::*,
+    Accessible, Box, Buildable, CompositeTemplate, ConstraintTarget, GestureClick, MenuButton, NamedAction,
+    PopoverMenu, Shortcut, Stack, ToggleButton, Widget, prelude::*, subclass::prelude::*,
 };
 use news_flash::models::{ArticleID, PluginCapabilities};
 use std::cell::{Cell, RefCell};
@@ -46,6 +48,11 @@ mod imp {
         #[template_child]
         pub share_popover: TemplateChild<SharePopover>,
 
+        #[template_child]
+        pub mark_article_read_button: TemplateChild<ToggleButton>,
+        #[template_child]
+        pub mark_article_button: TemplateChild<ToggleButton>,
+
         #[template_child]
         pub zoom_in_shortcut: TemplateChild<Shortcut>,
         #[template_child]
@@ -87,12 +94,41 @@ mod imp {
     #[glib::derived_properties]
     impl ObjectImpl for ArticleViewColumn {
         fn constructed(&self) {
-            self.insert_zoom_controls();
+            self.insert_menu_controls();
             self.bind_article_and_online();
             self.bind_scrape_content_button();
             self.bind_more_actions_stack();
             self.bind_can_tag();
 
+            // Setup dynamic tooltip bindings for keybindings
+            let keybindings_article_list = App::default().settings().keybindings().article_list();
+            let keybindings_article_view = App::default().settings().keybindings().article_view();
+
+            Self::bind_keybinding_tooltip(
+                keybindings_article_list.upcast_ref(),
+                "read",
+                self.mark_article_read_button.upcast_ref(),
+                i18n("Toggle Read"),
+            );
+            Self::bind_keybinding_tooltip(
+                keybindings_article_list.upcast_ref(),
+                "mark",
+                self.mark_article_button.upcast_ref(),
+                i18n("Toggle Starred"),
+            );
+            Self::bind_keybinding_tooltip(
+                keybindings_article_view.upcast_ref(),
+                "scrap-content",
+                self.scrape_content_button.upcast_ref(),
+                i18n("Try to Show Full Content"),
+            );
+            Self::bind_keybinding_tooltip(
+                keybindings_article_view.upcast_ref(),
+                "tag",
+                self.tag_button.upcast_ref(),
+                i18n("Tag Article"),
+            );
+
             let zoom_in_action = SimpleAction::new("zoom-in", None);
             zoom_in_action.connect_activate(clone!(
                 #[weak(rename_to = imp)]
@@ -131,11 +167,52 @@ mod imp {
                 }
             ));
 
+            let increase_fontsize_action = SimpleAction::new("increase-fontsize", None);
+            increase_fontsize_action.connect_activate(clone!(
+                #[weak(rename_to = imp)]
+                self,
+                #[upgrade_or_panic]
+                move |_action, _parameter| {
+                    let view = imp.article_view.get();
+                    let font_size = view.font_size();
+                    if font_size < constants::FONT_SIZE_UPPER {
+                        view.set_font_size(font_size + 1);
+                    }
+                }
+            ));
+
+            let decrease_fontsize_action = SimpleAction::new("decrease-fontsize", None);
+            decrease_fontsize_action.connect_activate(clone!(
+                #[weak(rename_to = imp)]
+                self,
+                #[upgrade_or_panic]
+                move |_action, _parameter| {
+                    let view = imp.article_view.get();
+                    let font_size = view.font_size();
+                    if font_size > constants::FONT_SIZE_LOWER {
+                        view.set_font_size(font_size - 1);
+                    }
+                }
+            ));
+
+            let reset_fontsize_action = SimpleAction::new("reset-fontsize", None);
+            reset_fontsize_action.connect_activate(clone!(
+                #[weak(rename_to = imp)]
+                self,
+                #[upgrade_or_panic]
+                move |_action, _parameter| {
+                    imp.article_view.set_font_size(constants::DEFAULT_FONT_SIZE);
+                }
+            ));
+
             let obj = self.obj();
             let action_group = SimpleActionGroup::new();
             action_group.add_action(&zoom_in_action);
             action_group.add_action(&zoom_out_action);
             action_group.add_action(&reset_zoom_action);
+            action_group.add_action(&increase_fontsize_action);
+            action_group.add_action(&decrease_fontsize_action);
+            action_group.add_action(&reset_fontsize_action);
             obj.insert_action_group("articleview", Some(&action_group));
 
             self.zoom_in_shortcut
@@ -206,6 +283,21 @@ mod imp {
             Self::bool_to_scrape_page(active)
         }
 
+        fn bind_keybinding_tooltip(source: &Object, source_property: &str, target: &Object, tooltip: String) {
+            source
+                .bind_property(source_property, target, "tooltip-text")
+                .transform_to(move |_binding, key_binding: Option<String>| {
+                    let combined_tooltip = key_binding
+                        .as_deref()
+                        .and_then(Keybindings::parse_shortcut_string)
+                        .map(|key| format!("{tooltip} ({key})"))
+                        .unwrap_or(tooltip.clone());
+                    Some(combined_tooltip)
+                })
+                .sync_create()
+                .build();
+        }
+
         fn bool_to_scrape_page(active: bool) -> &'static str {
             if active { "active" } else { "inactive" }
         }
@@ -293,53 +385,77 @@ mod imp {
             ));
         }
 
-        fn insert_zoom_controls(&self) {
+        fn insert_menu_controls(&self) {
             let Some(popover) = self.more_actions_button.popover().and_downcast::<PopoverMenu>() else {
                 return;
             };
 
-            let zoom_plus = Button::builder()
-                .icon_name("zoom-in-symbolic")
-                .tooltip_text("Zoom In")
-                .css_classes(vec!["circular", "flat"])
-                .action_name("articleview.zoom-in")
-                .build();
-            let zoom_minus = Button::builder()
-                .icon_name("zoom-out-symbolic")
-                .tooltip_text("Zoom Out")
-                .css_classes(vec!["circular", "flat"])
-                .action_name("articleview.zoom-out")
-                .build();
-            let zoom_reset = Button::builder()
-                .label("100%")
-                .tooltip_text("Reset Zoom")
-                .css_classes(vec!["flat"])
-                .action_name("articleview.reset-zoom")
-                .hexpand(true)
-                .build();
-            zoom_reset
-                .bind_property("label", &*self.article_view, "zoom")
-                .bidirectional()
-                .transform_from(|_binding, b: f64| Some(format!("{:.0}%", b * 100.0)))
-                .build();
-            let zoom_box = gtk4::Box::builder()
-                .spacing(12)
-                .orientation(Orientation::Horizontal)
-                .margin_start(18)
-                .margin_end(18)
-                .build();
-            zoom_box.append(&zoom_minus);
-            zoom_box.append(&zoom_reset);
-            zoom_box.append(&zoom_plus);
+            popover.connect_closed(|_popover| {
+                if let Err(error) = App::default().settings().write() {
+                    ContentPage::instance()
+                        .simple_message(&crate::i18n::i18n(&format!("Failed to write settings file: {error}")));
+                }
+            });
 
-            popover.add_child(&zoom_box, "zoom");
+            let articleview_settings = App::default().settings().article_view();
+
+            let zoom_control = crate::article_popover::ZoomControl::default();
+            self.article_view
+                .bind_property("zoom", &zoom_control, "percentage")
+                .transform_to(|_binding, b: f64| Some(format!("{:.0} %", b * 100.0)))
+                .build();
+
+            let font_style = crate::article_popover::FontStyle::default();
+            articleview_settings
+                .bind_property("font-style", &font_style, "font-style")
+                .bidirectional()
+                .sync_create()
+                .build();
+            font_style.connect_font_style_notify(clone!(
+                #[weak(rename_to = article_view)]
+                self.article_view,
+                move |_| article_view.redraw_article()
+            ));
+
+            let font_size = crate::article_popover::FontSizeControl::default();
+            articleview_settings
+                .bind_property("font-size", &font_size, "font-size")
+                .sync_create()
+                .build();
+
+            let content_width = crate::article_popover::Slider::default();
+            content_width.set_title("Content Width");
+            content_width.set_icon_name("content-width-symbolic");
+            content_width.add_marks(&[300.0, 450.0, 650.0, 900.0, 1200.0]);
+            articleview_settings
+                .bind_property("content-width", &content_width, "value")
+                .bidirectional()
+                .sync_create()
+                .build();
+
+            let line_height = crate::article_popover::Slider::default();
+            line_height.set_title("Line Height");
+            line_height.set_icon_name("line-height-symbolic");
+            line_height.add_marks(&[1.4, 1.8, 2.2, 2.6]);
+            articleview_settings
+                .bind_property("line-height", &line_height, "value")
+                .bidirectional()
+                .sync_create()
+                .build();
+
+            popover.add_child(&font_style, "font-style");
+            popover.add_child(&font_size, "font-size");
+            popover.add_child(&content_width, "content-width");
+            popover.add_child(&line_height, "line-height");
+            popover.add_child(&zoom_control, "zoom");
         }
     }
 }
 
 glib::wrapper! {
     pub struct ArticleViewColumn(ObjectSubclass<imp::ArticleViewColumn>)
-        @extends gtk4::Widget, gtk4::Box;
+        @extends Widget, Box,
+        @implements Accessible, Buildable, ConstraintTarget;
 }
 
 impl Default for ArticleViewColumn {
@@ -389,12 +505,10 @@ impl ArticleViewColumn {
                     }
 
                     if !MainWindow::instance().is_fullscreen() {
-                        let inner_splitview = ContentPage::instance().inner().clone();
-                        let show_article_view = inner_splitview.is_collapsed()
-                            && !inner_splitview.shows_content()
-                            && !this.block_next_view_switch();
-                        log::debug!("set show article view: {show_article_view}");
-                        inner_splitview.set_show_content(show_article_view);
+                        let show_article_view =
+                            ContentPage::instance().is_article_view_hidden() && !this.block_next_view_switch();
+                        tracing::debug!(%show_article_view);
+                        ContentPage::instance().show_article_view(show_article_view);
                     }
 
                     this.set_block_next_view_switch(false);
@@ -403,6 +517,37 @@ impl ArticleViewColumn {
         );
     }
 
+    pub fn reload(&self) {
+        let Some(article) = self.article() else {
+            return;
+        };
+
+        let article_id = article.article_id();
+
+        TokioRuntime::execute_with_callback(
+            move || async move {
+                let news_flash = App::news_flash();
+                let news_flash_guard = news_flash.read().await;
+                let news_flash = news_flash_guard.as_ref()?;
+                ArticleLoader::load(&article_id, news_flash)
+            },
+            clone!(
+                #[weak(rename_to = this)]
+                self,
+                move |res: Option<ArticleLoader>| {
+                    let Some(loader) = res else {
+                        return;
+                    };
+
+                    let imp = this.imp();
+                    let new_article = loader.build();
+
+                    imp.article_view.set_article(Some(new_article));
+                },
+            ),
+        );
+    }
+
     pub fn refresh_article_metadata_from_db(&self) {
         let Some(article) = self.article() else {
             return;
