@@ -1,10 +1,8 @@
 use std::time::Duration;
 
-use chrono::{NaiveTime, Utc};
 use gio::{ActionEntry, prelude::*};
 use glib::{Variant, VariantType};
 use gtk4::prelude::*;
-use libadwaita::prelude::*;
 use news_flash::error::NewsFlashError;
 use news_flash::models::{Article, ArticleFilter, ArticleID, CategoryID, FeedID, Marked, Read, TagID};
 
@@ -18,6 +16,7 @@ use crate::infrastructure::TokioRuntime;
 use crate::main_window::MainWindow;
 use crate::sidebar::{FeedListItemID, SideBar};
 use crate::undo_action::UndoAction;
+use crate::util::DateUtil;
 
 pub struct ArticleActions;
 
@@ -240,14 +239,7 @@ impl ArticleActions {
                 let news_flash_guad = news_flash.read().await;
                 let news_flash = news_flash_guad.as_ref().ok_or(NewsFlashError::NotLoggedIn)?;
 
-                let now = Utc::now();
-                let start = now.with_time(NaiveTime::from_hms_opt(0, 0, 0).unwrap()).unwrap();
-                let end = if App::default().settings().article_list().hide_future_articles() {
-                    now
-                } else {
-                    now.with_time(NaiveTime::from_hms_opt(23, 59, 59).unwrap()).unwrap()
-                };
-
+                let (start, end) = DateUtil::today_start_end();
                 let mut filter = ArticleFilter::all_unread();
                 filter.older_than = Some(end);
                 filter.newer_than = Some(start);
@@ -329,13 +321,7 @@ impl ArticleActions {
             match sidebar_selection.selection_type() {
                 SidebarSelectionType::All | SidebarSelectionType::None => {}
                 SidebarSelectionType::Today => {
-                    let now = Utc::now();
-                    let start = now.with_time(NaiveTime::from_hms_opt(0, 0, 0).unwrap()).unwrap();
-                    let end = if App::default().settings().article_list().hide_future_articles() {
-                        now
-                    } else {
-                        now.with_time(NaiveTime::from_hms_opt(23, 59, 59).unwrap()).unwrap()
-                    };
+                    let (start, end) = DateUtil::today_start_end();
                     filter.older_than = Some(end);
                     filter.newer_than = Some(start);
                 }
@@ -353,7 +339,7 @@ impl ArticleActions {
         match res {
             Err(error) => {
                 let message = i18n("Failed to mark read");
-                log::error!("{message}");
+                tracing::error!(%message);
                 ContentPage::instance().newsflash_error(&message, error);
             }
             Ok(articles) => {
@@ -392,7 +378,7 @@ impl ArticleActions {
             |res| {
                 if let Err(error) = res {
                     let message = i18n("Failed to mark multiple article ids read");
-                    log::error!("{message}");
+                    tracing::error!(%message);
                     ContentPage::instance().newsflash_error(&message, error);
                 }
 
@@ -412,9 +398,7 @@ impl ArticleActions {
     fn fullscreen_article() {
         let is_fullscreened = MainWindow::instance().is_fullscreen();
         MainWindow::instance().set_fullscreened(!is_fullscreened);
-        if let Some(article_navigation_page) = ContentPage::instance().inner().content() {
-            article_navigation_page.set_can_pop(is_fullscreened);
-        }
+        ContentPage::instance().set_article_view_can_pop(is_fullscreened);
     }
 
     fn toggle_selected_article_read() {
@@ -483,7 +467,7 @@ impl ArticleActions {
             move |res| {
                 if let Err(error) = res {
                     let message = i18n_f("Failed to mark article read: '{}'", &[&update.article_id.to_string()]);
-                    log::error!("{message}");
+                    tracing::error!(%message);
                     ContentPage::instance().newsflash_error(&message, error);
                     ArticleListColumn::instance().update_list();
                 }
@@ -521,7 +505,7 @@ impl ArticleActions {
             move |res| {
                 if let Err(error) = res {
                     let message = i18n_f("Failed to star article: '{}'", &[&update.article_id.to_string()]);
-                    log::error!("{message}");
+                    tracing::error!(%message);
                     ContentPage::instance().newsflash_error(&message, error);
                     ArticleListColumn::instance().update_list();
                 }
@@ -539,12 +523,12 @@ impl ArticleActions {
 
     fn copy_article_url() {
         let Some(article_model) = ArticleView::instance().article() else {
-            log::warn!("Copy article url to clipboard: No article Selected.");
+            tracing::warn!("Copy article url to clipboard: No article Selected.");
             return;
         };
 
         let Some(url) = article_model.url() else {
-            log::warn!("Copy article url to clipboard: No url available.");
+            tracing::warn!("Copy article url to clipboard: No url available.");
             return;
         };
 
@@ -589,7 +573,7 @@ impl ArticleActions {
                         let visible_article_id = ArticleView::instance().article().map(|article| article.article_id());
 
                         if visible_article_id.map(|id| id == scraped_article_id).unwrap_or(false) {
-                            ArticleViewColumn::instance().show_article(scraped_article_id, false);
+                            ArticleViewColumn::instance().reload();
                         }
 
                         if article.thumbnail_url.is_some() {
@@ -597,11 +581,11 @@ impl ArticleActions {
                         }
                     }
                     Ok(Err(error)) => {
-                        log::warn!("Internal scraper failed: {error}");
+                        tracing::warn!(%error, "Internal scraper failed");
                         ContentPage::instance().newsflash_error(&i18n("Scraper failed to extract content"), error);
                     }
                     Err(_error) => {
-                        log::warn!("Internal scraper elapsed");
+                        tracing::warn!("Internal scraper elapsed");
                         ContentPage::instance().simple_message(&i18n("Scraper Timeout"));
                     }
                 }
