@@ -174,7 +174,7 @@ impl EditActions {
             Some(CategoryID::from_owned(category_id))
         };
 
-        log::info!("add feed '{feed_url}'");
+        tracing::debug!(%feed_url, "add feed");
 
         TokioRuntime::execute_with_callback(
             || async move {
@@ -190,7 +190,7 @@ impl EditActions {
                     Self::fetch_feed(feed.feed_id);
                 }
                 Err(error) => {
-                    log::error!("Failed to add feed: {error}");
+                    tracing::error!(%error, "Failed to add feed");
                     ContentPage::instance().newsflash_error(&i18n("Failed to add feed"), error);
                 }
             },
@@ -254,7 +254,7 @@ impl EditActions {
             return;
         };
 
-        log::info!("add category '{title}'");
+        tracing::debug!(%title, "add category");
         let title = title.to_string();
 
         TokioRuntime::execute_with_callback(
@@ -267,7 +267,7 @@ impl EditActions {
             },
             |res| {
                 if let Err(error) = res {
-                    log::error!("Failed to add category: {error}");
+                    tracing::error!(%error, "Failed to add category");
                     ContentPage::instance().newsflash_error(&i18n("Failed to add category"), error);
                 } else {
                     ContentPage::instance().update_sidebar();
@@ -284,7 +284,7 @@ impl EditActions {
         let color = variant.child_get::<String>(0);
         let title = variant.child_get::<String>(1);
 
-        log::info!("add tag '{title}'");
+        tracing::debug!(%title, "add tag");
 
         TokioRuntime::execute_with_callback(
             || async move {
@@ -300,7 +300,7 @@ impl EditActions {
                     ArticleViewColumn::instance().refresh_article_metadata_from_db();
                 }
                 Err(error) => {
-                    log::error!("Failed to add tag: {error}");
+                    tracing::error!(%error, "Failed to add tag");
                     ContentPage::instance().newsflash_error(&i18n("Failed to add tag"), error);
                 }
             },
@@ -321,7 +321,7 @@ impl EditActions {
             },
             move |res| {
                 if let Err(error) = res {
-                    log::error!("Failed to delete category: {error}");
+                    tracing::error!(%error, "Failed to delete category");
                     ContentPage::instance().update_sidebar();
                     ContentPage::instance().newsflash_error(&i18n("Failed to delete category"), error);
                 }
@@ -343,7 +343,7 @@ impl EditActions {
             },
             move |res| {
                 if let Err(error) = res {
-                    log::error!("Failed to delete feed: {error}");
+                    tracing::error!(%error, "Failed to delete feed");
                     ContentPage::instance().update_sidebar();
                     ContentPage::instance().newsflash_error(&i18n("Failed to delete feed"), error);
                 }
@@ -365,7 +365,7 @@ impl EditActions {
             },
             move |res| {
                 if let Err(error) = res {
-                    log::error!("Failed to delete tag: {error}");
+                    tracing::error!(%error, "Failed to delete tag");
                     ContentPage::instance().update_sidebar();
                     ContentPage::instance().newsflash_error(&i18n("Failed to delete tag"), error);
                 }
@@ -375,7 +375,7 @@ impl EditActions {
 
     fn enqueue_delete_category(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("Delete category: no parameter");
+            tracing::warn!("Delete category: no parameter");
             return;
         };
 
@@ -393,7 +393,7 @@ impl EditActions {
 
     fn enqueue_delete_feed(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("Delete category: no parameter");
+            tracing::warn!("Delete category: no parameter");
             return;
         };
 
@@ -411,7 +411,7 @@ impl EditActions {
 
     fn enqueue_delete_tag(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("Delete category: no parameter");
+            tracing::warn!("Delete category: no parameter");
             return;
         };
 
@@ -429,7 +429,7 @@ impl EditActions {
 
     fn rename_feed(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("Rename feed: no parameter");
+            tracing::warn!("Rename feed: no parameter");
             return;
         };
 
@@ -465,7 +465,7 @@ impl EditActions {
                     }
                 }
                 Err(error) => {
-                    log::error!("Failed to rename feed: {error}");
+                    tracing::error!(%error, "Failed to rename feed");
                     ContentPage::instance().newsflash_error(&i18n("Failed to rename feed"), error);
                 }
             },
@@ -474,7 +474,7 @@ impl EditActions {
 
     fn rename_category(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("Rename category: no parameter");
+            tracing::warn!("Rename category: no parameter");
             return;
         };
 
@@ -503,7 +503,7 @@ impl EditActions {
                     ContentPage::instance().update_sidebar();
                 }
                 Err(error) => {
-                    log::error!("Failed to rename category: {error}");
+                    tracing::error!(%error, "Failed to rename category");
                     ContentPage::instance().newsflash_error(&i18n("Failed to rename category"), error);
                 }
             },
@@ -512,7 +512,7 @@ impl EditActions {
 
     fn edit_tag(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("Rename category: no parameter");
+            tracing::warn!("Rename category: no parameter");
             return;
         };
 
@@ -547,7 +547,7 @@ impl EditActions {
                 }
                 Err(error) => {
                     let message = &i18n("Failed to edit tag");
-                    log::error!("{message}");
+                    tracing::error!(%message);
                     ContentPage::instance().newsflash_error(message, error);
                 }
             },
@@ -556,7 +556,7 @@ impl EditActions {
 
     fn edit_feed_url(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("edit feed url: no parameter");
+            tracing::warn!("edit feed url: no parameter");
             return;
         };
 
@@ -580,7 +580,7 @@ impl EditActions {
             },
             move |res| {
                 if let Err(error) = res {
-                    log::error!("Failed to rename feed: {error}");
+                    tracing::error!(%error, "Failed to rename feed");
                     ContentPage::instance().newsflash_error(&i18n("Failed to rename feed"), error);
                 }
             },
@@ -589,7 +589,7 @@ impl EditActions {
 
     fn move_feed(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("move feed: no parameter");
+            tracing::warn!("move feed: no parameter");
             return;
         };
 
@@ -635,7 +635,7 @@ impl EditActions {
                     ContentPage::instance().update_sidebar();
                 }
                 Err(error) => {
-                    log::error!("Failed to move feed: {error}");
+                    tracing::error!(%error, "Failed to move feed");
                     ContentPage::instance().newsflash_error(&i18n("Failed to move feed"), error);
                 }
             },
@@ -644,7 +644,7 @@ impl EditActions {
 
     fn move_category(parameter: Option<&Variant>) {
         let Some(parameter) = parameter else {
-            log::warn!("move category: no parameter");
+            tracing::warn!("move category: no parameter");
             return;
         };
 
@@ -680,7 +680,7 @@ impl EditActions {
                     ContentPage::instance().update_sidebar();
                 }
                 Err(error) => {
-                    log::error!("Failed to move category: {error}");
+                    tracing::error!(%error, "Failed to move category");
                     ContentPage::instance().newsflash_error(&i18n("Failed to move category"), error);
                 }
             },
