@@ -1,20 +1,15 @@
 use glib::{Enum, prelude::*, translate::*};
 use news_flash::models::Marked;
 
-#[derive(Debug, Eq, PartialEq, Clone, Copy, Enum)]
+#[derive(Debug, Default, Eq, PartialEq, Clone, Copy, Enum)]
 #[repr(u32)]
 #[enum_type(name = "NewsFlashGMarked")]
 pub enum GMarked {
     Marked,
+    #[default]
     Unmarked,
 }
 
-impl Default for GMarked {
-    fn default() -> Self {
-        Self::Unmarked
-    }
-}
-
 impl From<Marked> for GMarked {
     fn from(marked: Marked) -> Self {
         match marked {
