@@ -1,20 +1,15 @@
 use glib::{Enum, prelude::*, translate::*};
 use news_flash::models::Read;
 
-#[derive(Debug, Eq, PartialEq, Clone, Copy, Enum)]
+#[derive(Debug, Default, Eq, PartialEq, Clone, Copy, Enum)]
 #[repr(u32)]
 #[enum_type(name = "NewsFlashGRead")]
 pub enum GRead {
+    #[default]
     Read,
     Unread,
 }
 
-impl Default for GRead {
-    fn default() -> Self {
-        Self::Read
-    }
-}
-
 impl From<Read> for GRead {
     fn from(read: Read) -> Self {
         match read {
