@@ -1,7 +1,7 @@
 use crate::app::App;
 use crate::i18n::i18n;
 use crate::util::ClockFormat;
-use chrono::{DateTime, Datelike, Local, TimeDelta, Utc};
+use chrono::{DateTime, Datelike, Local, NaiveTime, TimeDelta, TimeZone, Utc};
 
 pub struct DateUtil;
 
@@ -34,4 +34,17 @@ impl DateUtil {
             format!("{humand_readable}, {}", local_date.format("%Y"))
         }
     }
+
+    pub fn today_start_end() -> (DateTime<Utc>, DateTime<Utc>) {
+        let now = Local::now();
+        let start_local = now.with_time(NaiveTime::from_hms_opt(0, 0, 0).unwrap()).unwrap();
+        let start_utc_naive = start_local.naive_utc();
+        let start = Utc.from_local_datetime(&start_utc_naive).unwrap();
+
+        let end_local = now.with_time(NaiveTime::from_hms_opt(23, 59, 59).unwrap()).unwrap();
+        let end_utc_naive = end_local.naive_utc();
+        let end = Utc.from_local_datetime(&end_utc_naive).unwrap();
+
+        (start, end)
+    }
 }
